@@ -35,6 +35,8 @@ class Payment:
             'establishment_name': 'Cadena',  # opcional
             'sub_payments': []
         }
+        if 'site_id' in payment_data:
+            body['site_id'] = payment_data['site_id']
         if 'sub_payments' in payment_data:
             body['sub_payments'] = payment_data['sub_payments']
         if 'payment_type' in payment_data:
